"""Pytest configuration and fixtures."""

import pytest

# Configure pytest-asyncio to use auto mode
pytest_plugins = ("pytest_asyncio",)


@pytest.fixture(scope="session")
def event_loop_policy():
    """Use default event loop policy."""
    import asyncio

    return asyncio.DefaultEventLoopPolicy()
